using System;
using System.Collections.Generic;
using System.Data;
using UiPath.CodedWorkflows;
using UiPath.Core;
using UiPath.Core.Activities.Storage;
using UiPath.Orchestrator.Client.Models;
using UiPath.Testing;
using UiPath.Testing.Activities.TestData;
using UiPath.Testing.Activities.TestDataQueues.Enums;
using UiPath.Testing.Enums;
using UiPath.UIAutomationNext.API.Contracts;
using UiPath.UIAutomationNext.API.Models;
using UiPath.UIAutomationNext.Enums;

// NOTICE: The Coded Automations feature is available as a preview feature and APIs may be subject to change. 
//         No warranty or technical support is provided for this preview feature.
//         Missing features or encountering bugs? Please click the feedback button in the top-right corner and let us know!
// Please delete these comments after you've read and acknowledged them. For more information, please visit the documentation over at https://docs.uipath.com/studio/lang-en/v2023.4/docs/coded-automations.
namespace Coded_Test_Case_UiBank
{
			
	public class applyForLoan : CodedWorkflow
    {
		// Reference the LoanApplication in this file's context
        private LoanApplication myLoanApplication;
		
		[TestCase]
        public void Execute()
        {
            // Arrange
            Log("Test run started for applyForLoan.");
			InitializeTestData(); 
				// Open the UiBank application and choose to apply for a loan
				var homeScreen = uiAutomation.Open("HomeScreen");
				homeScreen.Click("Products");
				homeScreen.Click("Loans");
				
				// Apply for a loan
				var applyForLoanScreen = uiAutomation.Attach("ApplyForLoan");
				applyForLoanScreen.Click("ApplyForALoan");
				
				// Fill in the loan application form with test data
				var loanApplicationForm = uiAutomation.Open("LoanApplication");
				loanApplicationForm.TypeInto("EmailAddress", myLoanApplication.email);
				loanApplicationForm.TypeInto("LoanAmountRequested", myLoanApplication.loanAmount.ToString());
				loanApplicationForm.SelectItem("LoanTerm", "5");
				Log(loanApplicationForm.ToString());
				loanApplicationForm.TypeInto("CurrentYearlyIncome","30000");
				loanApplicationForm.TypeInto("Age", myLoanApplication.age.ToString());
			
            // Act
            	// Click the Submit button
				loanApplicationForm.Click("SubmitLoanApplication");

            // Assert
            	// Get the generated loan rate and compare it with the one you expected it to be
				var loanResultsScreen = uiAutomation.Attach("LoanResults");
				var actualLoanRate = loanResultsScreen.GetText("LoanRate");
				testing.VerifyExpression(actualLoanRate == myLoanApplication.expectedLoanRate.ToString(),"The expected and actual loan rates are equal",true, "Verify Expression", true, false);
        }
			// Prepare the test data, using the LoanApplication
			public void InitializeTestData(){
			
				myLoanApplication = new LoanApplication();
				myLoanApplication.age = 42;
				myLoanApplication.email = "john.doe@uipath.com";
				myLoanApplication.income = 30000;
				myLoanApplication.loanAmount = decimal.ToInt32(testing.RandomNumber(20000,30000,0));
				myLoanApplication.loanTerm =5;
				myLoanApplication.expectedLoanRate = 8;
		}
	
} 

}